@@ -21,7 +21,8 @@ RE_N_RANK = re.compile(r"\#[\d]+")
 RE_DOLLARS = re.compile(r"\$[\d\,\.]+")
 RE_POSSESSIVE = re.compile(r"\b[\w]+[']s\b")
 RE_MULTI_SPACE = re.compile(r"\s{2,}")
-RE_CLEAN_TITLE = re.compile(r"[^\w\'\,\ ]+")
+RE_UPPERCASE = re.compile(r"[A-Z]")
+RE_CLEAN_TITLE = re.compile(r"[^\w\'\,\-\ ]+")
 RE_DELIMITERS = re.compile(r"[\n\.]")
 RE_IMAGE = re.compile(r"!\[[^\]]*\]\([^\)]+\)")
 RE_IMAGES = re.compile(r"!\[[^\]]*\]\([^\)]+\)[\s]{0,}!\[[^\]]*\]\([^\)]+\)")
@@ -1297,9 +1298,10 @@ class Scrutineer:
             body, self._max_user_tags, self._full
         )
 
-        tags = []
-        if "tags" in post["json_metadata"]:
-            tags = post["json_metadata"]["tags"]
+        metadata = post["json_metadata"]
+        if isinstance(metadata, str):
+            metadata = json.loads(metadata)
+        tags = metadata.get("tags", [])
         self.analysis["tags"] = _analyze_tags(tags, self._max_tags, self._full)
 
         score = 0
@@ -1333,11 +1335,10 @@ def _analyze_title(title, keywords, full=False):
     cleaned = RE_N_RANK.sub(" ", cleaned)
     cleaned = RE_DOLLARS.sub(" ", cleaned)
     cleaned = RE_POSSESSIVE.sub("", cleaned)
+    cleaned = RE_CLEAN_TITLE.sub(" ", cleaned)
     cleaned = RE_MULTI_SPACE.sub(" ", cleaned).strip()
     length = len(cleaned.encode("utf-8"))
 
-    words = RE_CLEAN_TITLE.sub(" ", title.lower()).split(" ")
-
     bmin = length < 20
     amax = length > 80
 
@@ -1346,8 +1347,10 @@ def _analyze_title(title, keywords, full=False):
     readability = 0
 
     if length:
+        uppercase = len(RE_UPPERCASE.findall(cleaned))/length
+        adjust = (1, 0.5)[int(bool(uppercase>0.5))]
         english = _to_english(cleaned, chars=True)
-        readability = english / len(title)
+        readability = (english / len(title)) * adjust
         if isinstance(keywords, dict):
             words = title.lower()
             for keyword in keywords.keys():
@@ -1365,6 +1368,7 @@ def _analyze_title(title, keywords, full=False):
         "cleaned": cleaned,
         "below_min": bmin,
         "above_max": amax,
+        "uppercase": uppercase,
         "keywords": keywords,
         "readability": readability,
         "keyword_score": skeywords,
